==> SAGElyzer_1.3.0.tar.gz: SAGElyzer/R/getGEOSAGE.R <==
# These functions get the SAGE files from NCBI and save the files in
# the data directory by default or somewhere as defined by users.
#
# Copyright 2002, J. Zhang. All rights reserved.
#
getGEOSAGE <- function(organism = "human", targetDir = "", quiet = TRUE,
               url = "http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?"){

    if(targetDir == "")
        targetDir <- file.path(.path.package("SAGElyzer"), "temp")

    fileNames <- getFileNames(organism, url)

    for(i in fileNames){
        if(!quiet){
            print(paste("Downloading file:", i))
        }
        geo <- GEO(url)
        geoData <- readData(geo, i)
        write.table(geoData, file =  file.path(targetDir,
                             paste(i, ".sage", sep = "")),
                    quote = FALSE, sep = "\t", row.names = FALSE,
                    col.names = FALSE)
    }
}

getFileNames <- function(organism, url){
    switch(tolower(organism),
           "human" = gpl <- "GPL4",
           "mouse" = gpl <- "GPL11",
           "rat" = gpl <- "GPL23",
           stop("The organism is not supported this time"))

    fullUrl <- paste(url, "acc=", gpl, "&form=text&&view=data", sep = "")
    ids <- getSampleId(fullUrl)

    return(ids)
}

getSampleId <- function(url){
    ids <- NULL
    con <- url(url, open = "r")
    idFile <- readLines(con)
    for(i in idFile){
        if(regexpr("^!Platform_sample", i) > 0)
            ids <- c(ids, gsub("^!Platform_sample_id = ", "", i))
    }
    return(ids)
}
# Not useful now
#parseSAGE <- function(inName, outName){

#    perlName <- file.path(.path.package("SAGElyzer"), "exec",
#                         "GEOSAGEParser.pl")
#    OST <- .Platform$OS.type
#    if (OST == "windows")
#        shell.exec(paste("perl", perlName, inName, outName))
#    else if (OST == "unix")
#        system(paste("perl", perlName, inName, outName))
#    else
#        stop("don't know how to run perl")
#}

==> SAGElyzer_1.10.0.tar.gz: SAGElyzer/R/getGEOSAGE.R <==
# These functions get the SAGE files from NCBI and save the files in
# the data directory by default or somewhere as defined by users.
#
# Copyright 2002, J. Zhang. All rights reserved.
#
getGEOSAGE <- function(organism = "human", targetDir = "", quiet = TRUE,
               url = "http://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?"){

    if(targetDir == "")
        targetDir <- file.path(.path.package("SAGElyzer"), "temp")

    fileNames <- getFileNames(organism, url)

    for(i in fileNames){
        if(!quiet){
            print(paste("Downloading file:", i))
        }
        geo <- GEO(url)
        geoData <- readData(geo, i)
        write.table(geoData, file =  file.path(targetDir,
                             paste(i, ".sage", sep = "")),
                    quote = FALSE, sep = "\t", row.names = FALSE,
                    col.names = FALSE)
    }
}

getFileNames <- function(organism, url){
    switch(tolower(organism),
           "human" = gpl <- "GPL4",
           "mouse" = gpl <- "GPL11",
           "rat" = gpl <- "GPL23",
           stop("The organism is not supported this time"))

    fullUrl <- paste(url, "acc=", gpl, "&form=text", sep = "")
    ids <- getSampleId(fullUrl)

    return(ids)
}

getSampleId <- function(url){
    ids <- NULL
    con <- url(url, open = "r")
    idFile <- readLines(con)
    for(i in idFile){
        if(regexpr("^!Platform_sample", i) > 0)
            ids <- c(ids, gsub("^!Platform_sample_id = ", "", i))
    }
    return(ids)
}
# Not useful now
#parseSAGE <- function(inName, outName){

#    perlName <- file.path(.path.package("SAGElyzer"), "exec",
#                         "GEOSAGEParser.pl")
#    OST <- .Platform$OS.type
#    if (OST == "windows")
#        shell.exec(paste("perl", perlName, inName, outName))
#    else if (OST == "unix")
#        system(paste("perl", perlName, inName, outName))
#    else
#        stop("don't know how to run perl")
#}
